Module api

Module api 

Structs

AddIdpCredentialRequest
The request for creating an IdpCredential with its associated payload. An InboundSamlSsoProfile can own up to 2 credentials.
CancelUserInvitationRequest
Request to cancel sent invitation for target email in UserInvitation.
CheckTransitiveMembershipResponse
The response message for MembershipsService.CheckTransitiveMembership.
CloudIdentity
Central instance to access all CloudIdentity related resource activities
CustomerMethods
A builder providing access to all methods supported on customer resources. It is not used directly, but through the CloudIdentity hub.
CustomerUserinvitationCancelCall
Cancels a UserInvitation that was already sent.
CustomerUserinvitationGetCall
Retrieves a UserInvitation resource. Note: New consumer accounts with the customer’s verified domain created within the previous 48 hours will not appear in the result. This delay also applies to newly-verified domains.
CustomerUserinvitationIsInvitableUserCall
Verifies whether a user account is eligible to receive a UserInvitation (is an unmanaged account). Eligibility is based on the following criteria: * the email address is a consumer account and it’s the primary email address of the account, and * the domain of the email address matches an existing verified Google Workspace or Cloud Identity domain If both conditions are met, the user is eligible. Note: This method is not supported for Workspace Essentials customers.
CustomerUserinvitationListCall
Retrieves a list of UserInvitation resources. Note: New consumer accounts with the customer’s verified domain created within the previous 48 hours will not appear in the result. This delay also applies to newly-verified domains.
CustomerUserinvitationSendCall
Sends a UserInvitation to email. If the UserInvitation does not exist for this request and it is a valid request, the request creates a UserInvitation. Note: The get and list methods have a 48-hour delay where newly-created consumer accounts will not appear in the results. You can still send a UserInvitation to those accounts if you know the unmanaged email address and IsInvitableUser==True.
DeviceCancelWipeCall
Cancels an unfinished device wipe. This operation can be used to cancel device wipe in the gap between the wipe operation returning success and the device being wiped. This operation is possible when the device is in a “pending wipe” state. The device enters the “pending wipe” state when a wipe device command is issued, but has not yet been sent to the device. The cancel wipe will fail if the wipe command has already been issued to the device.
DeviceCreateCall
Creates a device. Only company-owned device may be created. Note: This method is available only to customers who have one of the following SKUs: Enterprise Standard, Enterprise Plus, Enterprise for Education, and Cloud Identity Premium
DeviceDeleteCall
Deletes the specified device.
DeviceDeviceUserApproveCall
Approves device to access user data.
DeviceDeviceUserBlockCall
Blocks device from accessing user data
DeviceDeviceUserCancelWipeCall
Cancels an unfinished user account wipe. This operation can be used to cancel device wipe in the gap between the wipe operation returning success and the device being wiped.
DeviceDeviceUserClientStateGetCall
Gets the client state for the device user
DeviceDeviceUserClientStateListCall
Lists the client states for the given search query.
DeviceDeviceUserClientStatePatchCall
Updates the client state for the device user Note: This method is available only to customers who have one of the following SKUs: Enterprise Standard, Enterprise Plus, Enterprise for Education, and Cloud Identity Premium
DeviceDeviceUserDeleteCall
Deletes the specified DeviceUser. This also revokes the user’s access to device data.
DeviceDeviceUserGetCall
Retrieves the specified DeviceUser
DeviceDeviceUserListCall
Lists/Searches DeviceUsers.
DeviceDeviceUserLookupCall
Looks up resource names of the DeviceUsers associated with the caller’s credentials, as well as the properties provided in the request. This method must be called with end-user credentials with the scope: https://www.googleapis.com/auth/cloud-identity.devices.lookup If multiple properties are provided, only DeviceUsers having all of these properties are considered as matches - i.e. the query behaves like an AND. Different platforms require different amounts of information from the caller to ensure that the DeviceUser is uniquely identified. - iOS: Specifying the ‘partner’ and ‘ios_device_id’ fields is required. - Android: Specifying the ‘android_id’ field is required. - Desktop: Specifying the ‘raw_resource_id’ field is required.
DeviceDeviceUserWipeCall
Wipes the user’s account on a device. Other data on the device that is not associated with the user’s work account is not affected. For example, if a Gmail app is installed on a device that is used for personal and work purposes, and the user is logged in to the Gmail app with their personal account as well as their work account, wiping the “deviceUser” by their work administrator will not affect their personal account within Gmail or other apps such as Photos.
DeviceGetCall
Retrieves the specified device.
DeviceListCall
Lists/Searches devices.
DeviceMethods
A builder providing access to all methods supported on device resources. It is not used directly, but through the CloudIdentity hub.
DeviceWipeCall
Wipes all data on the specified device.
DsaPublicKeyInfo
Information of a DSA public key.
DynamicGroupMetadata
Dynamic group metadata like queries and status.
DynamicGroupQuery
Defines a query on a resource.
DynamicGroupStatus
The current status of a dynamic group along with timestamp.
EntityKey
A unique identifier for an entity in the Cloud Identity Groups API. An entity can represent either a group with an optional namespace or a user without a namespace. The combination of id and namespace must be unique; however, the same id can be used with different namespaces.
ExpiryDetail
The MembershipRole expiry details.
GoogleAppsCloudidentityDevicesV1AndroidAttributes
Resource representing the Android specific attributes of a Device.
GoogleAppsCloudidentityDevicesV1ApproveDeviceUserRequest
Request message for approving the device to access user data.
GoogleAppsCloudidentityDevicesV1BlockDeviceUserRequest
Request message for blocking account on device.
GoogleAppsCloudidentityDevicesV1BrowserAttributes
Contains information about browser profiles reported by the Endpoint Verification extension.
GoogleAppsCloudidentityDevicesV1BrowserInfo
Browser-specific fields reported by the Endpoint Verification extension.
GoogleAppsCloudidentityDevicesV1CancelWipeDeviceRequest
Request message for cancelling an unfinished device wipe.
GoogleAppsCloudidentityDevicesV1CancelWipeDeviceUserRequest
Request message for cancelling an unfinished user account wipe.
GoogleAppsCloudidentityDevicesV1CertificateAttributes
Stores information about a certificate.
GoogleAppsCloudidentityDevicesV1CertificateTemplate
CertificateTemplate (v3 Extension in X.509).
GoogleAppsCloudidentityDevicesV1ClientState
Represents the state associated with an API client calling the Devices API. Resource representing ClientState and supports updates from API users
GoogleAppsCloudidentityDevicesV1CustomAttributeValue
Additional custom attribute values may be one of these types
GoogleAppsCloudidentityDevicesV1Device
A Device within the Cloud Identity Devices API. Represents a Device known to Google Cloud, independent of the device ownership, type, and whether it is assigned or in use by a user.
GoogleAppsCloudidentityDevicesV1DeviceUser
Represents a user’s use of a Device in the Cloud Identity Devices API. A DeviceUser is a resource representing a user’s use of a Device
GoogleAppsCloudidentityDevicesV1EndpointVerificationSpecificAttributes
Resource representing the Endpoint Verification-specific attributes of a device.
GoogleAppsCloudidentityDevicesV1ListClientStatesResponse
Response message that is returned in ListClientStates.
GoogleAppsCloudidentityDevicesV1ListDeviceUsersResponse
Response message that is returned from the ListDeviceUsers method.
GoogleAppsCloudidentityDevicesV1ListDevicesResponse
Response message that is returned from the ListDevices method.
GoogleAppsCloudidentityDevicesV1LookupSelfDeviceUsersResponse
Response containing resource names of the DeviceUsers associated with the caller’s credentials.
GoogleAppsCloudidentityDevicesV1WipeDeviceRequest
Request message for wiping all data on the device.
GoogleAppsCloudidentityDevicesV1WipeDeviceUserRequest
Request message for starting an account wipe on device.
Group
A group within the Cloud Identity Groups API. A Group is a collection of entities, where each entity is either a user, another group, or a service account.
GroupCreateCall
Creates a Group.
GroupDeleteCall
Deletes a Group.
GroupGetCall
Retrieves a Group.
GroupGetSecuritySettingCall
Get Security Settings
GroupListCall
Lists the Group resources under a customer or namespace.
GroupLookupCall
Looks up the resource name of a Group by its EntityKey.
GroupMembershipCheckTransitiveMembershipCall
Check a potential member for membership in a group. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the member is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. A member has membership to a group as long as there is a single viewable transitive membership between the group and the member. The actor must have view permissions to at least one transitive membership between the member and group.
GroupMembershipCreateCall
Creates a Membership.
GroupMembershipDeleteCall
Deletes a Membership.
GroupMembershipGetCall
Retrieves a Membership.
GroupMembershipGetMembershipGraphCall
Get a membership graph of just a member or both a member and a group. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the member is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. Given a member, the response will contain all membership paths from the member. Given both a group and a member, the response will contain all membership paths between the group and the member.
GroupMembershipListCall
Lists the Memberships within a Group.
GroupMembershipLookupCall
Looks up the resource name of a Membership by its EntityKey.
GroupMembershipModifyMembershipRoleCall
Modifies the MembershipRoles of a Membership.
GroupMembershipSearchDirectGroupCall
Searches direct groups of a member.
GroupMembershipSearchTransitiveGroupCall
Search transitive groups of a member. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the member is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. A transitive group is any group that has a direct or indirect membership to the member. Actor must have view permissions all transitive groups.
GroupMembershipSearchTransitiveMembershipCall
Search transitive memberships of a group. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the group is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. A transitive membership is any direct or indirect membership of a group. Actor must have view permissions to all transitive memberships.
GroupMethods
A builder providing access to all methods supported on group resources. It is not used directly, but through the CloudIdentity hub.
GroupPatchCall
Updates a Group.
GroupRelation
Message representing a transitive group of a user or a group.
GroupSearchCall
Searches for Group resources matching a specified query.
GroupUpdateSecuritySettingCall
Update Security Settings
IdpCredential
Credential for verifying signatures produced by the Identity Provider.
InboundOidcSsoProfile
An OIDC federation between a Google enterprise customer and an OIDC identity provider.
InboundOidcSsoProfileCreateCall
Creates an InboundOidcSsoProfile for a customer. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
InboundOidcSsoProfileDeleteCall
Deletes an InboundOidcSsoProfile.
InboundOidcSsoProfileGetCall
Gets an InboundOidcSsoProfile.
InboundOidcSsoProfileListCall
Lists InboundOidcSsoProfile objects for a Google enterprise customer.
InboundOidcSsoProfileMethods
A builder providing access to all methods supported on inboundOidcSsoProfile resources. It is not used directly, but through the CloudIdentity hub.
InboundOidcSsoProfilePatchCall
Updates an InboundOidcSsoProfile. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
InboundSamlSsoProfile
A SAML 2.0 federation between a Google enterprise customer and a SAML identity provider.
InboundSamlSsoProfileCreateCall
Creates an InboundSamlSsoProfile for a customer. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
InboundSamlSsoProfileDeleteCall
Deletes an InboundSamlSsoProfile.
InboundSamlSsoProfileGetCall
Gets an InboundSamlSsoProfile.
InboundSamlSsoProfileIdpCredentialAddCall
Adds an IdpCredential. Up to 2 credentials are allowed. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
InboundSamlSsoProfileIdpCredentialDeleteCall
Deletes an IdpCredential.
InboundSamlSsoProfileIdpCredentialGetCall
Gets an IdpCredential.
InboundSamlSsoProfileIdpCredentialListCall
Returns a list of IdpCredentials in an InboundSamlSsoProfile.
InboundSamlSsoProfileListCall
Lists InboundSamlSsoProfiles for a customer.
InboundSamlSsoProfileMethods
A builder providing access to all methods supported on inboundSamlSsoProfile resources. It is not used directly, but through the CloudIdentity hub.
InboundSamlSsoProfilePatchCall
Updates an InboundSamlSsoProfile. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
InboundSsoAssignment
Targets with “set” SSO assignments and their respective assignments.
InboundSsoAssignmentCreateCall
Creates an InboundSsoAssignment for users and devices in a Customer under a given Group or OrgUnit.
InboundSsoAssignmentDeleteCall
Deletes an InboundSsoAssignment. To disable SSO, Create (or Update) an assignment that has sso_mode == SSO_OFF.
InboundSsoAssignmentGetCall
Gets an InboundSsoAssignment.
InboundSsoAssignmentListCall
Lists the InboundSsoAssignments for a Customer.
InboundSsoAssignmentMethods
A builder providing access to all methods supported on inboundSsoAssignment resources. It is not used directly, but through the CloudIdentity hub.
InboundSsoAssignmentPatchCall
Updates an InboundSsoAssignment. The body of this request is the inbound_sso_assignment field and the update_mask is relative to that. For example: a PATCH to /v1/inboundSsoAssignments/0abcdefg1234567&update_mask=rank with a body of { "rank": 1 } moves that (presumably group-targeted) SSO assignment to the highest priority and shifts any other group-targeted assignments down in priority.
IsInvitableUserResponse
Response for IsInvitableUser RPC.
ListGroupsResponse
Response message for ListGroups operation.
ListIdpCredentialsResponse
Response of the InboundSamlSsoProfilesService.ListIdpCredentials method.
ListInboundOidcSsoProfilesResponse
Response of the InboundOidcSsoProfilesService.ListInboundOidcSsoProfiles method.
ListInboundSamlSsoProfilesResponse
Response of the InboundSamlSsoProfilesService.ListInboundSamlSsoProfiles method.
ListInboundSsoAssignmentsResponse
Response of the InboundSsoAssignmentsService.ListInboundSsoAssignments method.
ListMembershipsResponse
The response message for MembershipsService.ListMemberships.
ListPoliciesResponse
The response message for PoliciesService.ListPolicies.
ListUserInvitationsResponse
Response message for UserInvitation listing request.
LookupGroupNameResponse
The response message for GroupsService.LookupGroupName.
LookupMembershipNameResponse
The response message for MembershipsService.LookupMembershipName.
MemberRelation
Message representing a transitive membership of a group.
MemberRestriction
The definition of MemberRestriction
Membership
A membership within the Cloud Identity Groups API. A Membership defines a relationship between a Group and an entity belonging to that Group, referred to as a “member”.
MembershipRelation
Message containing membership relation.
MembershipRole
A membership role within the Cloud Identity Groups API. A MembershipRole defines the privileges granted to a Membership.
MembershipRoleRestrictionEvaluation
The evaluated state of this restriction.
ModifyMembershipRolesRequest
The request message for MembershipsService.ModifyMembershipRoles.
ModifyMembershipRolesResponse
The response message for MembershipsService.ModifyMembershipRoles.
OidcIdpConfig
OIDC IDP (identity provider) configuration.
OidcRpConfig
OIDC RP (relying party) configuration.
OidcSsoInfo
Details that are applicable when sso_mode is set to OIDC_SSO.
Operation
This resource represents a long-running operation that is the result of a network API call.
Policy
A Policy resource binds an instance of a single Setting with the scope of a PolicyQuery. The Setting instance will be applied to all entities that satisfy the query.
PolicyGetCall
Get a policy.
PolicyListCall
List policies.
PolicyMethods
A builder providing access to all methods supported on policy resources. It is not used directly, but through the CloudIdentity hub.
PolicyQuery
PolicyQuery
RestrictionEvaluation
The evaluated state of this restriction.
RestrictionEvaluations
Evaluations of restrictions applied to parent group on this membership.
RsaPublicKeyInfo
Information of a RSA public key.
SamlIdpConfig
SAML IDP (identity provider) configuration.
SamlSpConfig
SAML SP (service provider) configuration.
SamlSsoInfo
Details that are applicable when sso_mode == SAML_SSO.
SearchDirectGroupsResponse
The response message for MembershipsService.SearchDirectGroups.
SearchGroupsResponse
The response message for GroupsService.SearchGroups.
SearchTransitiveGroupsResponse
The response message for MembershipsService.SearchTransitiveGroups.
SearchTransitiveMembershipsResponse
The response message for MembershipsService.SearchTransitiveMemberships.
SecuritySettings
The definition of security settings.
SendUserInvitationRequest
A request to send email for inviting target user corresponding to the UserInvitation.
Setting
Setting
SignInBehavior
Controls sign-in behavior.
Status
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
TransitiveMembershipRole
Message representing the role of a TransitiveMembership.
UpdateMembershipRolesParams
The details of an update to a MembershipRole.
UserInvitation
The UserInvitation resource represents an email that can be sent to an unmanaged user account inviting them to join the customer’s Google Workspace or Cloud Identity account. An unmanaged account shares an email address domain with the Google Workspace or Cloud Identity account but is not managed by it yet. If the user accepts the UserInvitation, the user account will become managed.

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.