pub struct CheckTransitiveMembershipResponse {
pub has_membership: Option<bool>,
}Expand description
The response message for MembershipsService.CheckTransitiveMembership.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
has_membership: Option<bool>Response does not include the possible roles of a member since the behavior of this rpc is not all-or-nothing unlike the other rpcs. So, it may not be possible to list all the roles definitively, due to possible lack of authorization in some of the paths.