pub struct CustomerMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on customer resources.
It is not used directly, but through the CloudIdentity hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_cloudidentity1 as cloudidentity1;
use cloudidentity1::{CloudIdentity, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudIdentity::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `userinvitations_cancel(...)`, `userinvitations_get(...)`, `userinvitations_is_invitable_user(...)`, `userinvitations_list(...)` and `userinvitations_send(...)`
// to build up your call.
let rb = hub.customers();Implementations
Sourceimpl<'a, C> CustomerMethods<'a, C>
impl<'a, C> CustomerMethods<'a, C>
Sourcepub fn userinvitations_cancel(
&self,
request: CancelUserInvitationRequest,
name: &str,
) -> CustomerUserinvitationCancelCall<'a, C>
pub fn userinvitations_cancel( &self, request: CancelUserInvitationRequest, name: &str, ) -> CustomerUserinvitationCancelCall<'a, C>
Create a builder to help you perform the following task:
Cancels a UserInvitation that was already sent.
Arguments
request- No description provided.name- Required.UserInvitationname in the formatcustomers/{customer}/userinvitations/{user_email_address}
Sourcepub fn userinvitations_get(
&self,
name: &str,
) -> CustomerUserinvitationGetCall<'a, C>
pub fn userinvitations_get( &self, name: &str, ) -> CustomerUserinvitationGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a UserInvitation resource. Note: New consumer accounts with the customer’s verified domain created within the previous 48 hours will not appear in the result. This delay also applies to newly-verified domains.
Arguments
name- Required.UserInvitationname in the formatcustomers/{customer}/userinvitations/{user_email_address}
Sourcepub fn userinvitations_is_invitable_user(
&self,
name: &str,
) -> CustomerUserinvitationIsInvitableUserCall<'a, C>
pub fn userinvitations_is_invitable_user( &self, name: &str, ) -> CustomerUserinvitationIsInvitableUserCall<'a, C>
Create a builder to help you perform the following task:
Verifies whether a user account is eligible to receive a UserInvitation (is an unmanaged account). Eligibility is based on the following criteria: * the email address is a consumer account and it’s the primary email address of the account, and * the domain of the email address matches an existing verified Google Workspace or Cloud Identity domain If both conditions are met, the user is eligible. Note: This method is not supported for Workspace Essentials customers.
Arguments
name- Required.UserInvitationname in the formatcustomers/{customer}/userinvitations/{user_email_address}
Sourcepub fn userinvitations_list(
&self,
parent: &str,
) -> CustomerUserinvitationListCall<'a, C>
pub fn userinvitations_list( &self, parent: &str, ) -> CustomerUserinvitationListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of UserInvitation resources. Note: New consumer accounts with the customer’s verified domain created within the previous 48 hours will not appear in the result. This delay also applies to newly-verified domains.
Arguments
parent- Required. The customer ID of the Google Workspace or Cloud Identity account the UserInvitation resources are associated with.
Sourcepub fn userinvitations_send(
&self,
request: SendUserInvitationRequest,
name: &str,
) -> CustomerUserinvitationSendCall<'a, C>
pub fn userinvitations_send( &self, request: SendUserInvitationRequest, name: &str, ) -> CustomerUserinvitationSendCall<'a, C>
Create a builder to help you perform the following task:
Sends a UserInvitation to email. If the UserInvitation does not exist for this request and it is a valid request, the request creates a UserInvitation. Note: The get and list methods have a 48-hour delay where newly-created consumer accounts will not appear in the results. You can still send a UserInvitation to those accounts if you know the unmanaged email address and IsInvitableUser==True.
Arguments
request- No description provided.name- Required.UserInvitationname in the formatcustomers/{customer}/userinvitations/{user_email_address}