Struct google_cloudidentity1::api::DeviceDeviceUserWipeCall [−][src]
Wipes the user’s account on a device. Other data on the device that is not associated with the user’s work account is not affected. For example, if a Gmail app is installed on a device that is used for personal and work purposes, and the user is logged in to the Gmail app with their personal account as well as their work account, wiping the “deviceUser” by their work administrator will not affect their personal account within Gmail or other apps such as Photos.
A builder for the deviceUsers.wipe method supported by a device resource.
It is not used directly, but through a DeviceMethods instance.
Example
Instantiate a resource method builder
use cloudidentity1::api::GoogleAppsCloudidentityDevicesV1WipeDeviceUserRequest; // As the method needs a request, you would usually fill it with the desired information // into the respective structure. Some of the parts shown here might not be applicable ! // Values shown here are possibly random and not representative ! let mut req = GoogleAppsCloudidentityDevicesV1WipeDeviceUserRequest::default(); // You can configure optional parameters by calling the respective setters at will, and // execute the final call using `doit()`. // Values shown here are possibly random and not representative ! let result = hub.devices().device_users_wipe(req, "name") .doit().await;
Implementations
impl<'a> DeviceDeviceUserWipeCall<'a>[src]
pub async fn doit(self) -> Result<(Response<Body>, Operation)>[src]
Perform the operation you have build so far.
pub fn request(
self,
new_value: GoogleAppsCloudidentityDevicesV1WipeDeviceUserRequest
) -> DeviceDeviceUserWipeCall<'a>[src]
self,
new_value: GoogleAppsCloudidentityDevicesV1WipeDeviceUserRequest
) -> DeviceDeviceUserWipeCall<'a>
Sets the request property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
pub fn name(self, new_value: &str) -> DeviceDeviceUserWipeCall<'a>[src]
Required. Resource name of the Device in format: devices/{device_id}/deviceUsers/{device_user_id}, where device_id is the unique ID assigned to the Device, and device_user_id is the unique ID assigned to the User.
Sets the name path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
pub fn delegate(
self,
new_value: &'a mut dyn Delegate
) -> DeviceDeviceUserWipeCall<'a>[src]
self,
new_value: &'a mut dyn Delegate
) -> DeviceDeviceUserWipeCall<'a>
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.
Sets the delegate property to the given value.
pub fn param<T>(self, name: T, value: T) -> DeviceDeviceUserWipeCall<'a> where
T: AsRef<str>, [src]
T: AsRef<str>,
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- $.xgafv (query-string) - V1 error format.
- access_token (query-string) - OAuth access token.
- alt (query-string) - Data format for response.
- callback (query-string) - JSONP
- fields (query-string) - Selector specifying which fields to include in a partial response.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
- upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).