Struct google_cloudidentity1::api::DeviceListCall [−][src]
Lists/Searches devices.
A builder for the list method supported by a device resource.
It is not used directly, but through a DeviceMethods instance.
Example
Instantiate a resource method builder
// You can configure optional parameters by calling the respective setters at will, and // execute the final call using `doit()`. // Values shown here are possibly random and not representative ! let result = hub.devices().list() .view("vero") .page_token("erat") .page_size(-93) .order_by("duo") .filter("dolore") .customer("et") .doit().await;
Implementations
impl<'a> DeviceListCall<'a>[src]
pub async fn doit(
self
) -> Result<(Response<Body>, GoogleAppsCloudidentityDevicesV1ListDevicesResponse)>[src]
self
) -> Result<(Response<Body>, GoogleAppsCloudidentityDevicesV1ListDevicesResponse)>
Perform the operation you have build so far.
pub fn view(self, new_value: &str) -> DeviceListCall<'a>[src]
Optional. The view to use for the List request.
Sets the view query property to the given value.
pub fn page_token(self, new_value: &str) -> DeviceListCall<'a>[src]
Optional. A page token, received from a previous ListDevices call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListDevices must match the call that provided the page token.
Sets the page token query property to the given value.
pub fn page_size(self, new_value: i32) -> DeviceListCall<'a>[src]
Optional. The maximum number of Devices to return. If unspecified, at most 20 Devices will be returned. The maximum value is 100; values above 100 will be coerced to 100.
Sets the page size query property to the given value.
pub fn order_by(self, new_value: &str) -> DeviceListCall<'a>[src]
Optional. Order specification for devices in the response. Only one of the following field names may be used to specify the order: create_time, last_sync_time, model, os_version, device_type and serial_number. desc may be specified optionally at the end to specify results to be sorted in descending order. Default order is ascending.
Sets the order by query property to the given value.
pub fn filter(self, new_value: &str) -> DeviceListCall<'a>[src]
Optional. Additional restrictions when fetching list of devices. For a list of search fields, refer to Mobile device search fields. Multiple search fields are separated by the space character.
Sets the filter query property to the given value.
pub fn customer(self, new_value: &str) -> DeviceListCall<'a>[src]
Optional. Resource name of the customer in the format: customers/{customer_id}, where customer_id is the customer to whom the device belongs. If you’re using this API for your own organization, use customers/my_customer. If you’re using this API to manage another organization, use customers/{customer_id}, where customer_id is the customer to whom the device belongs.
Sets the customer query property to the given value.
pub fn delegate(self, new_value: &'a mut dyn Delegate) -> DeviceListCall<'a>[src]
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.
Sets the delegate property to the given value.
pub fn param<T>(self, name: T, value: T) -> DeviceListCall<'a> where
T: AsRef<str>, [src]
T: AsRef<str>,
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- $.xgafv (query-string) - V1 error format.
- access_token (query-string) - OAuth access token.
- alt (query-string) - Data format for response.
- callback (query-string) - JSONP
- fields (query-string) - Selector specifying which fields to include in a partial response.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
- upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).