pub struct DynamicGroupQuery {
pub query: Option<String>,
pub resource_type: Option<String>,
}Expand description
Defines a query on a resource.
This type is not used in any activity, and only used as part of another schema.
Fields
query: Option<String>Query that determines the memberships of the dynamic group. Examples: All users with at least one organizations.department of engineering. user.organizations.exists(org, org.department=='engineering') All users with at least one location that has area of foo and building_id of bar. user.locations.exists(loc, loc.area=='foo' && loc.building_id=='bar') All users with any variation of the name John Doe (case-insensitive queries add equalsIgnoreCase() to the value being queried). user.name.value.equalsIgnoreCase('jOhn DoE')
resource_type: Option<String>Resource type for the Dynamic Group Query