pub struct EntityKey {
pub id: Option<String>,
pub namespace: Option<String>,
}Expand description
A unique identifier for an entity in the Cloud Identity Groups API. An entity can represent either a group with an optional namespace or a user without a namespace. The combination of id and namespace must be unique; however, the same id can be used with different namespaces.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The ID of the entity. For Google-managed entities, the id should be the email address of an existing group or user. Email addresses need to adhere to name guidelines for users and groups. For external-identity-mapped entities, the id must be a string conforming to the Identity Source’s requirements. Must be unique within a namespace.
namespace: Option<String>The namespace in which the entity exists. If not specified, the EntityKey represents a Google-managed entity such as a Google user or a Google Group. If specified, the EntityKey represents an external-identity-mapped group. The namespace must correspond to an identity source created in Admin Console and must be in the form of identitysources/{identity_source}.