pub struct GoogleAppsCloudidentityDevicesV1AndroidAttributes {
pub cts_profile_match: Option<bool>,
pub enabled_unknown_sources: Option<bool>,
pub has_potentially_harmful_apps: Option<bool>,
pub owner_profile_account: Option<bool>,
pub ownership_privilege: Option<String>,
pub supports_work_profile: Option<bool>,
pub verified_boot: Option<bool>,
pub verify_apps_enabled: Option<bool>,
}Expand description
Resource representing the Android specific attributes of a Device.
This type is not used in any activity, and only used as part of another schema.
Fields
cts_profile_match: Option<bool>Whether the device passes Android CTS compliance.
enabled_unknown_sources: Option<bool>Whether applications from unknown sources can be installed on device.
has_potentially_harmful_apps: Option<bool>Whether any potentially harmful apps were detected on the device.
owner_profile_account: Option<bool>Whether this account is on an owner/primary profile. For phones, only true for owner profiles. Android 4+ devices can have secondary or restricted user profiles.
ownership_privilege: Option<String>Ownership privileges on device.
supports_work_profile: Option<bool>Whether device supports Android work profiles. If false, this service will not block access to corp data even if an administrator turns on the “Enforce Work Profile” policy.
verified_boot: Option<bool>Whether Android verified boot status is GREEN.
verify_apps_enabled: Option<bool>Whether Google Play Protect Verify Apps is enabled.