pub struct GoogleAppsCloudidentityDevicesV1BlockDeviceUserRequest {
pub customer: Option<String>,
}Expand description
Request message for blocking account on device.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- device users block devices (request)
Fields
customer: Option<String>Optional. Resource name of the customer. If you’re using this API for your own organization, use customers/my_customer If you’re using this API to manage another organization, use customers/{customer}, where customer is the customer to whom the device belongs.