pub struct GoogleAppsCloudidentityDevicesV1CustomAttributeValue {
pub bool_value: Option<bool>,
pub number_value: Option<f64>,
pub string_value: Option<String>,
}Expand description
Additional custom attribute values may be one of these types
This type is not used in any activity, and only used as part of another schema.
Fields
bool_value: Option<bool>Represents a boolean value.
number_value: Option<f64>Represents a double value.
string_value: Option<String>Represents a string value.