Struct google_cloudidentity1::api::Group[][src]

pub struct Group {
    pub create_time: Option<String>,
    pub description: Option<String>,
    pub display_name: Option<String>,
    pub dynamic_group_metadata: Option<DynamicGroupMetadata>,
    pub group_key: Option<EntityKey>,
    pub labels: Option<HashMap<String, String>>,
    pub name: Option<String>,
    pub parent: Option<String>,
    pub update_time: Option<String>,
}

A group within the Cloud Identity Groups API. A Group is a collection of entities, where each entity is either a user, another group, or a service account.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

create_time: Option<String>

Output only. The time when the Group was created.

description: Option<String>

An extended description to help users determine the purpose of a Group. Must not be longer than 4,096 characters.

display_name: Option<String>

The display name of the Group.

dynamic_group_metadata: Option<DynamicGroupMetadata>

Optional. Dynamic group metadata like queries and status.

group_key: Option<EntityKey>

Required. Immutable. The EntityKey of the Group.

labels: Option<HashMap<String, String>>

Required. One or more label entries that apply to the Group. Currently supported labels contain a key with an empty value. Google Groups are the default type of group and have a label with a key of cloudidentity.googleapis.com/groups.discussion_forum and an empty value. Existing Google Groups can have an additional label with a key of cloudidentity.googleapis.com/groups.security and an empty value added to them. This is an immutable change and the security label cannot be removed once added. Dynamic groups have a label with a key of cloudidentity.googleapis.com/groups.dynamic. Identity-mapped groups for Cloud Search have a label with a key of system/groups/external and an empty value. Examples: {“cloudidentity.googleapis.com/groups.discussion_forum”: “”} or {“system/groups/external”: “”}.

name: Option<String>

Output only. The resource name of the Group. Shall be of the form groups/{group_id}.

parent: Option<String>

Required. Immutable. The resource name of the entity under which this Group resides in the Cloud Identity resource hierarchy. Must be of the form identitysources/{identity_source_id} for external- identity-mapped groups or customers/{customer_id} for Google Groups.

update_time: Option<String>

Output only. The time when the Group was last updated.