pub struct GroupRelation {
pub display_name: Option<String>,
pub group: Option<String>,
pub group_key: Option<EntityKey>,
pub labels: Option<HashMap<String, String>>,
pub relation_type: Option<String>,
pub roles: Option<Vec<TransitiveMembershipRole>>,
}Expand description
Message representing a transitive group of a user or a group.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Display name for this group.
group: Option<String>Resource name for this group.
group_key: Option<EntityKey>Entity key has an id and a namespace. In case of discussion forums, the id will be an email address without a namespace.
labels: Option<HashMap<String, String>>Labels for Group resource.
relation_type: Option<String>The relation between the member and the transitive group.
roles: Option<Vec<TransitiveMembershipRole>>Membership roles of the member for the group.