pub struct IdpCredential {
pub dsa_key_info: Option<DsaPublicKeyInfo>,
pub name: Option<String>,
pub rsa_key_info: Option<RsaPublicKeyInfo>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
Credential for verifying signatures produced by the Identity Provider.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
dsa_key_info: Option<DsaPublicKeyInfo>Output only. Information of a DSA public key.
name: Option<String>Output only. Resource name of the credential.
rsa_key_info: Option<RsaPublicKeyInfo>Output only. Information of a RSA public key.
update_time: Option<DateTime<Utc>>Output only. Time when the IdpCredential was last updated.