pub struct InboundSamlSsoProfileMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on inboundSamlSsoProfile resources.
It is not used directly, but through the CloudIdentity hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_cloudidentity1 as cloudidentity1;
use cloudidentity1::{CloudIdentity, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudIdentity::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `create(...)`, `delete(...)`, `get(...)`, `idp_credentials_add(...)`, `idp_credentials_delete(...)`, `idp_credentials_get(...)`, `idp_credentials_list(...)`, `list(...)` and `patch(...)`
// to build up your call.
let rb = hub.inbound_saml_sso_profiles();Implementations
Sourceimpl<'a, C> InboundSamlSsoProfileMethods<'a, C>
impl<'a, C> InboundSamlSsoProfileMethods<'a, C>
Sourcepub fn idp_credentials_add(
&self,
request: AddIdpCredentialRequest,
parent: &str,
) -> InboundSamlSsoProfileIdpCredentialAddCall<'a, C>
pub fn idp_credentials_add( &self, request: AddIdpCredentialRequest, parent: &str, ) -> InboundSamlSsoProfileIdpCredentialAddCall<'a, C>
Create a builder to help you perform the following task:
Adds an IdpCredential. Up to 2 credentials are allowed. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
Arguments
request- No description provided.parent- Required. The InboundSamlSsoProfile that owns the IdpCredential. Format:inboundSamlSsoProfiles/{sso_profile_id}
Sourcepub fn idp_credentials_delete(
&self,
name: &str,
) -> InboundSamlSsoProfileIdpCredentialDeleteCall<'a, C>
pub fn idp_credentials_delete( &self, name: &str, ) -> InboundSamlSsoProfileIdpCredentialDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes an IdpCredential.
Arguments
name- Required. The resource name of the IdpCredential to delete. Format:inboundSamlSsoProfiles/{sso_profile_id}/idpCredentials/{idp_credential_id}
Sourcepub fn idp_credentials_get(
&self,
name: &str,
) -> InboundSamlSsoProfileIdpCredentialGetCall<'a, C>
pub fn idp_credentials_get( &self, name: &str, ) -> InboundSamlSsoProfileIdpCredentialGetCall<'a, C>
Create a builder to help you perform the following task:
Gets an IdpCredential.
Arguments
name- Required. The resource name of the IdpCredential to retrieve. Format:inboundSamlSsoProfiles/{sso_profile_id}/idpCredentials/{idp_credential_id}
Sourcepub fn idp_credentials_list(
&self,
parent: &str,
) -> InboundSamlSsoProfileIdpCredentialListCall<'a, C>
pub fn idp_credentials_list( &self, parent: &str, ) -> InboundSamlSsoProfileIdpCredentialListCall<'a, C>
Create a builder to help you perform the following task:
Returns a list of IdpCredentials in an InboundSamlSsoProfile.
Arguments
parent- Required. The parent, which owns this collection ofIdpCredentials. Format:inboundSamlSsoProfiles/{sso_profile_id}
Sourcepub fn create(
&self,
request: InboundSamlSsoProfile,
) -> InboundSamlSsoProfileCreateCall<'a, C>
pub fn create( &self, request: InboundSamlSsoProfile, ) -> InboundSamlSsoProfileCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates an InboundSamlSsoProfile for a customer. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
Arguments
request- No description provided.
Sourcepub fn delete(&self, name: &str) -> InboundSamlSsoProfileDeleteCall<'a, C>
pub fn delete(&self, name: &str) -> InboundSamlSsoProfileDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes an InboundSamlSsoProfile.
Arguments
name- Required. The resource name of the InboundSamlSsoProfile to delete. Format:inboundSamlSsoProfiles/{sso_profile_id}
Sourcepub fn get(&self, name: &str) -> InboundSamlSsoProfileGetCall<'a, C>
pub fn get(&self, name: &str) -> InboundSamlSsoProfileGetCall<'a, C>
Create a builder to help you perform the following task:
Gets an InboundSamlSsoProfile.
Arguments
name- Required. The resource name of the InboundSamlSsoProfile to get. Format:inboundSamlSsoProfiles/{sso_profile_id}
Sourcepub fn list(&self) -> InboundSamlSsoProfileListCall<'a, C>
pub fn list(&self) -> InboundSamlSsoProfileListCall<'a, C>
Create a builder to help you perform the following task:
Lists InboundSamlSsoProfiles for a customer.
Sourcepub fn patch(
&self,
request: InboundSamlSsoProfile,
name: &str,
) -> InboundSamlSsoProfilePatchCall<'a, C>
pub fn patch( &self, request: InboundSamlSsoProfile, name: &str, ) -> InboundSamlSsoProfilePatchCall<'a, C>
Create a builder to help you perform the following task:
Updates an InboundSamlSsoProfile. When the target customer has enabled Multi-party approval for sensitive actions, the Operation in the response will have "done": false, it will not have a response, and the metadata will have "state": "awaiting-multi-party-approval".
Arguments
request- No description provided.name- Output only. Resource name of the SAML SSO profile.