pub struct InboundSsoAssignmentMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on inboundSsoAssignment resources.
It is not used directly, but through the CloudIdentity hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_cloudidentity1 as cloudidentity1;
use cloudidentity1::{CloudIdentity, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudIdentity::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `create(...)`, `delete(...)`, `get(...)`, `list(...)` and `patch(...)`
// to build up your call.
let rb = hub.inbound_sso_assignments();Implementations
Sourceimpl<'a, C> InboundSsoAssignmentMethods<'a, C>
impl<'a, C> InboundSsoAssignmentMethods<'a, C>
Sourcepub fn create(
&self,
request: InboundSsoAssignment,
) -> InboundSsoAssignmentCreateCall<'a, C>
pub fn create( &self, request: InboundSsoAssignment, ) -> InboundSsoAssignmentCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates an InboundSsoAssignment for users and devices in a Customer under a given Group or OrgUnit.
Arguments
request- No description provided.
Sourcepub fn delete(&self, name: &str) -> InboundSsoAssignmentDeleteCall<'a, C>
pub fn delete(&self, name: &str) -> InboundSsoAssignmentDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes an InboundSsoAssignment. To disable SSO, Create (or Update) an assignment that has sso_mode == SSO_OFF.
Arguments
name- Required. The resource name of the InboundSsoAssignment to delete. Format:inboundSsoAssignments/{assignment}
Sourcepub fn get(&self, name: &str) -> InboundSsoAssignmentGetCall<'a, C>
pub fn get(&self, name: &str) -> InboundSsoAssignmentGetCall<'a, C>
Create a builder to help you perform the following task:
Gets an InboundSsoAssignment.
Arguments
name- Required. The resource name of the InboundSsoAssignment to fetch. Format:inboundSsoAssignments/{assignment}
Sourcepub fn list(&self) -> InboundSsoAssignmentListCall<'a, C>
pub fn list(&self) -> InboundSsoAssignmentListCall<'a, C>
Create a builder to help you perform the following task:
Lists the InboundSsoAssignments for a Customer.
Sourcepub fn patch(
&self,
request: InboundSsoAssignment,
name: &str,
) -> InboundSsoAssignmentPatchCall<'a, C>
pub fn patch( &self, request: InboundSsoAssignment, name: &str, ) -> InboundSsoAssignmentPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates an InboundSsoAssignment. The body of this request is the inbound_sso_assignment field and the update_mask is relative to that. For example: a PATCH to /v1/inboundSsoAssignments/0abcdefg1234567&update_mask=rank with a body of { "rank": 1 } moves that (presumably group-targeted) SSO assignment to the highest priority and shifts any other group-targeted assignments down in priority.
Arguments
request- No description provided.name- Output only. Resource name of the Inbound SSO Assignment.