pub struct IsInvitableUserResponse {
pub is_invitable_user: Option<bool>,
}Expand description
Response for IsInvitableUser RPC.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- userinvitations is invitable user customers (response)
Fields
is_invitable_user: Option<bool>Returns true if the email address is invitable.