pub struct ListInboundSamlSsoProfilesResponse {
pub inbound_saml_sso_profiles: Option<Vec<InboundSamlSsoProfile>>,
pub next_page_token: Option<String>,
}Expand description
Response of the InboundSamlSsoProfilesService.ListInboundSamlSsoProfiles method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list inbound saml sso profiles (response)
Fields
inbound_saml_sso_profiles: Option<Vec<InboundSamlSsoProfile>>List of InboundSamlSsoProfiles.
next_page_token: Option<String>A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.