pub struct ListMembershipsResponse {
pub memberships: Option<Vec<Membership>>,
pub next_page_token: Option<String>,
}Expand description
The response message for MembershipsService.ListMemberships.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- memberships list groups (response)
Fields
memberships: Option<Vec<Membership>>The Memberships under the specified parent.
next_page_token: Option<String>A continuation token to retrieve the next page of results, or empty if there are no more results available.