pub struct ListUserInvitationsResponse {
pub next_page_token: Option<String>,
pub user_invitations: Option<Vec<UserInvitation>>,
}Expand description
Response message for UserInvitation listing request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- userinvitations list customers (response)
Fields
next_page_token: Option<String>The token for the next page. If not empty, indicates that there may be more UserInvitation resources that match the listing request; this value can be used in a subsequent ListUserInvitationsRequest to get continued results with the current list call.
user_invitations: Option<Vec<UserInvitation>>The list of UserInvitation resources.