Struct google_cloudidentity1::api::MemberRelation[][src]

pub struct MemberRelation {
    pub member: Option<String>,
    pub preferred_member_key: Option<Vec<EntityKey>>,
    pub relation_type: Option<String>,
    pub roles: Option<Vec<TransitiveMembershipRole>>,
}

Message representing a transitive membership of a group.

This type is not used in any activity, and only used as part of another schema.

Fields

member: Option<String>

Resource name for this member if member is a GROUP, otherwise it is empty.

preferred_member_key: Option<Vec<EntityKey>>

Entity key has an id and a namespace. In case of discussion forums, the id will be an email address without a namespace.

relation_type: Option<String>

The relation between the group and the transitive member.

roles: Option<Vec<TransitiveMembershipRole>>

The membership role details (i.e name of role and expiry time).