pub struct MembershipRelation {
pub description: Option<String>,
pub display_name: Option<String>,
pub group: Option<String>,
pub group_key: Option<EntityKey>,
pub labels: Option<HashMap<String, String>>,
pub membership: Option<String>,
pub roles: Option<Vec<MembershipRole>>,
}Expand description
Message containing membership relation.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>An extended description to help users determine the purpose of a Group.
display_name: Option<String>The display name of the Group.
group: Option<String>The resource name of the Group. Shall be of the form groups/{group_id}.
group_key: Option<EntityKey>The EntityKey of the Group.
labels: Option<HashMap<String, String>>One or more label entries that apply to the Group. Currently supported labels contain a key with an empty value.
membership: Option<String>The resource name of the Membership. Shall be of the form groups/{group_id}/memberships/{membership_id}.
roles: Option<Vec<MembershipRole>>The MembershipRoles that apply to the Membership.