pub struct RestrictionEvaluations {
pub member_restriction_evaluation: Option<MembershipRoleRestrictionEvaluation>,
}Expand description
Evaluations of restrictions applied to parent group on this membership.
This type is not used in any activity, and only used as part of another schema.
Fields
member_restriction_evaluation: Option<MembershipRoleRestrictionEvaluation>Evaluation of the member restriction applied to this membership. Empty if the user lacks permission to view the restriction evaluation.