SamlIdpConfig

Struct SamlIdpConfig 

pub struct SamlIdpConfig {
    pub change_password_uri: Option<String>,
    pub entity_id: Option<String>,
    pub logout_redirect_uri: Option<String>,
    pub single_sign_on_service_uri: Option<String>,
}
SAML IDP (identity provider) configuration.

This type is not used in any activity, and only used as part of another schema.

Fields

change_password_uri: Option<String>

The Change Password URL of the identity provider. Users will be sent to this URL when changing their passwords at myaccount.google.com. This takes precedence over the change password URL configured at customer-level. Must use HTTPS.

entity_id: Option<String>

Required. The SAML Entity ID of the identity provider.

logout_redirect_uri: Option<String>

The Logout Redirect URL (sign-out page URL) of the identity provider. When a user clicks the sign-out link on a Google page, they will be redirected to this URL. This is a pure redirect with no attached SAML LogoutRequest i.e. SAML single logout is not supported. Must use HTTPS.

single_sign_on_service_uri: Option<String>

Required. The SingleSignOnService endpoint location (sign-in page URL) of the identity provider. This is the URL where the AuthnRequest will be sent. Must use HTTPS. Assumed to accept the HTTP-Redirect binding.