pub struct SearchGroupsResponse {
pub groups: Option<Vec<Group>>,
pub next_page_token: Option<String>,
}Expand description
The response message for GroupsService.SearchGroups.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- search groups (response)
Fields
groups: Option<Vec<Group>>The Group resources that match the search query.
next_page_token: Option<String>A continuation token to retrieve the next page of results, or empty if there are no more results available.