pub struct SearchTransitiveGroupsResponse {
pub memberships: Option<Vec<GroupRelation>>,
pub next_page_token: Option<String>,
}Expand description
The response message for MembershipsService.SearchTransitiveGroups.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- memberships search transitive groups groups (response)
Fields
memberships: Option<Vec<GroupRelation>>List of transitive groups satisfying the query.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results available for listing.