pub struct SendUserInvitationRequest { /* private fields */ }Expand description
A request to send email for inviting target user corresponding to the UserInvitation.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- userinvitations send customers (request)