UserInvitation

Struct UserInvitation 

pub struct UserInvitation {
    pub mails_sent_count: Option<i64>,
    pub name: Option<String>,
    pub state: Option<String>,
    pub update_time: Option<DateTime<Utc>>,
}
The UserInvitation resource represents an email that can be sent to an unmanaged user account inviting them to join the customer’s Google Workspace or Cloud Identity account. An unmanaged account shares an email address domain with the Google Workspace or Cloud Identity account but is not managed by it yet. If the user accepts the UserInvitation, the user account will become managed.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

mails_sent_count: Option<i64>

Number of invitation emails sent to the user.

name: Option<String>

Shall be of the form customers/{customer}/userinvitations/{user_email_address}.

state: Option<String>

State of the UserInvitation.

update_time: Option<DateTime<Utc>>

Time when the UserInvitation was last updated.