Struct google_cloudidentity1::api::GoogleAppsCloudidentityDevicesV1ApproveDeviceUserRequest[][src]

pub struct GoogleAppsCloudidentityDevicesV1ApproveDeviceUserRequest {
    pub customer: Option<String>,
}

Request message for approving the device to access user data.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

customer: Option<String>

Optional. Resource name of the customer. If you’re using this API for your own organization, use customers/my_customer If you’re using this API to manage another organization, use customers/{customer_id}, where customer_id is the customer to whom the device belongs.