pub struct GoogleAppsCloudidentityDevicesV1BrowserAttributes {
pub chrome_browser_info: Option<GoogleAppsCloudidentityDevicesV1BrowserInfo>,
pub chrome_profile_id: Option<String>,
pub last_profile_sync_time: Option<DateTime<Utc>>,
}Expand description
Contains information about browser profiles reported by the Endpoint Verification extension.
This type is not used in any activity, and only used as part of another schema.
Fields
chrome_browser_info: Option<GoogleAppsCloudidentityDevicesV1BrowserInfo>Represents the current state of the Chrome browser attributes sent by the Endpoint Verification extension.
chrome_profile_id: Option<String>Chrome profile ID that is exposed by the Chrome API. It is unique for each device.
last_profile_sync_time: Option<DateTime<Utc>>Timestamp in milliseconds since the Unix epoch when the profile/gcm id was last synced.