pub struct GroupMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on group resources.
It is not used directly, but through the CloudIdentity hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_cloudidentity1 as cloudidentity1;
use cloudidentity1::{CloudIdentity, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudIdentity::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `create(...)`, `delete(...)`, `get(...)`, `get_security_settings(...)`, `list(...)`, `lookup(...)`, `memberships_check_transitive_membership(...)`, `memberships_create(...)`, `memberships_delete(...)`, `memberships_get(...)`, `memberships_get_membership_graph(...)`, `memberships_list(...)`, `memberships_lookup(...)`, `memberships_modify_membership_roles(...)`, `memberships_search_direct_groups(...)`, `memberships_search_transitive_groups(...)`, `memberships_search_transitive_memberships(...)`, `patch(...)`, `search(...)` and `update_security_settings(...)`
// to build up your call.
let rb = hub.groups();Implementations
Sourceimpl<'a, C> GroupMethods<'a, C>
impl<'a, C> GroupMethods<'a, C>
Sourcepub fn memberships_check_transitive_membership(
&self,
parent: &str,
) -> GroupMembershipCheckTransitiveMembershipCall<'a, C>
pub fn memberships_check_transitive_membership( &self, parent: &str, ) -> GroupMembershipCheckTransitiveMembershipCall<'a, C>
Create a builder to help you perform the following task:
Check a potential member for membership in a group. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the member is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. A member has membership to a group as long as there is a single viewable transitive membership between the group and the member. The actor must have view permissions to at least one transitive membership between the member and group.
Arguments
parent- Resource name of the group to check the transitive membership in. Format:groups/{group}, wheregroupis the unique id assigned to the Group to which the Membership belongs to.
Sourcepub fn memberships_create(
&self,
request: Membership,
parent: &str,
) -> GroupMembershipCreateCall<'a, C>
pub fn memberships_create( &self, request: Membership, parent: &str, ) -> GroupMembershipCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a Membership.
Arguments
request- No description provided.parent- Required. The parentGroupresource under which to create theMembership. Must be of the formgroups/{group}.
Sourcepub fn memberships_delete(&self, name: &str) -> GroupMembershipDeleteCall<'a, C>
pub fn memberships_delete(&self, name: &str) -> GroupMembershipDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a Membership.
Arguments
name- Required. The resource name of theMembershipto delete. Must be of the formgroups/{group}/memberships/{membership}
Sourcepub fn memberships_get(&self, name: &str) -> GroupMembershipGetCall<'a, C>
pub fn memberships_get(&self, name: &str) -> GroupMembershipGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a Membership.
Arguments
name- Required. The resource name of theMembershipto retrieve. Must be of the formgroups/{group}/memberships/{membership}.
Sourcepub fn memberships_get_membership_graph(
&self,
parent: &str,
) -> GroupMembershipGetMembershipGraphCall<'a, C>
pub fn memberships_get_membership_graph( &self, parent: &str, ) -> GroupMembershipGetMembershipGraphCall<'a, C>
Create a builder to help you perform the following task:
Get a membership graph of just a member or both a member and a group. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the member is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. Given a member, the response will contain all membership paths from the member. Given both a group and a member, the response will contain all membership paths between the group and the member.
Arguments
parent- Required. Resource name of the group to search transitive memberships in. Format:groups/{group}, wheregroupis the unique ID assigned to the Group to which the Membership belongs to. group can be a wildcard collection id “-”. When a group is specified, the membership graph will be constrained to paths between the member (defined in the query) and the parent. If a wildcard collection is provided, all membership paths connected to the member will be returned.
Sourcepub fn memberships_list(&self, parent: &str) -> GroupMembershipListCall<'a, C>
pub fn memberships_list(&self, parent: &str) -> GroupMembershipListCall<'a, C>
Create a builder to help you perform the following task:
Lists the Memberships within a Group.
Arguments
parent- Required. The parentGroupresource under which to lookup theMembershipname. Must be of the formgroups/{group}.
Sourcepub fn memberships_lookup(
&self,
parent: &str,
) -> GroupMembershipLookupCall<'a, C>
pub fn memberships_lookup( &self, parent: &str, ) -> GroupMembershipLookupCall<'a, C>
Create a builder to help you perform the following task:
Looks up the resource name of a Membership by its EntityKey.
Arguments
parent- Required. The parentGroupresource under which to lookup theMembershipname. Must be of the formgroups/{group}.
Sourcepub fn memberships_modify_membership_roles(
&self,
request: ModifyMembershipRolesRequest,
name: &str,
) -> GroupMembershipModifyMembershipRoleCall<'a, C>
pub fn memberships_modify_membership_roles( &self, request: ModifyMembershipRolesRequest, name: &str, ) -> GroupMembershipModifyMembershipRoleCall<'a, C>
Create a builder to help you perform the following task:
Modifies the MembershipRoles of a Membership.
Arguments
request- No description provided.name- Required. The resource name of theMembershipwhose roles are to be modified. Must be of the formgroups/{group}/memberships/{membership}.
Sourcepub fn memberships_search_direct_groups(
&self,
parent: &str,
) -> GroupMembershipSearchDirectGroupCall<'a, C>
pub fn memberships_search_direct_groups( &self, parent: &str, ) -> GroupMembershipSearchDirectGroupCall<'a, C>
Create a builder to help you perform the following task:
Searches direct groups of a member.
Arguments
parent- Resource name of the group to search transitive memberships in. Format: groups/{group_id}, where group_id is always ‘-’ as this API will search across all groups for a given member.
Sourcepub fn memberships_search_transitive_groups(
&self,
parent: &str,
) -> GroupMembershipSearchTransitiveGroupCall<'a, C>
pub fn memberships_search_transitive_groups( &self, parent: &str, ) -> GroupMembershipSearchTransitiveGroupCall<'a, C>
Create a builder to help you perform the following task:
Search transitive groups of a member. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the member is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. A transitive group is any group that has a direct or indirect membership to the member. Actor must have view permissions all transitive groups.
Arguments
parent- Resource name of the group to search transitive memberships in. Format:groups/{group}, wheregroupis always ‘-’ as this API will search across all groups for a given member.
Sourcepub fn memberships_search_transitive_memberships(
&self,
parent: &str,
) -> GroupMembershipSearchTransitiveMembershipCall<'a, C>
pub fn memberships_search_transitive_memberships( &self, parent: &str, ) -> GroupMembershipSearchTransitiveMembershipCall<'a, C>
Create a builder to help you perform the following task:
Search transitive memberships of a group. Note: This feature is only available to Google Workspace Enterprise Standard, Enterprise Plus, and Enterprise for Education; and Cloud Identity Premium accounts. If the account of the group is not one of these, a 403 (PERMISSION_DENIED) HTTP status code will be returned. A transitive membership is any direct or indirect membership of a group. Actor must have view permissions to all transitive memberships.
Arguments
parent- Resource name of the group to search transitive memberships in. Format:groups/{group}, wheregroupis the unique ID assigned to the Group.
Sourcepub fn create(&self, request: Group) -> GroupCreateCall<'a, C>
pub fn create(&self, request: Group) -> GroupCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a Group.
Arguments
request- No description provided.
Sourcepub fn delete(&self, name: &str) -> GroupDeleteCall<'a, C>
pub fn delete(&self, name: &str) -> GroupDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a Group.
Arguments
name- Required. The resource name of theGroupto retrieve. Must be of the formgroups/{group}.
Sourcepub fn get(&self, name: &str) -> GroupGetCall<'a, C>
pub fn get(&self, name: &str) -> GroupGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a Group.
Arguments
name- Required. The resource name of theGroupto retrieve. Must be of the formgroups/{group}.
Sourcepub fn get_security_settings(
&self,
name: &str,
) -> GroupGetSecuritySettingCall<'a, C>
pub fn get_security_settings( &self, name: &str, ) -> GroupGetSecuritySettingCall<'a, C>
Create a builder to help you perform the following task:
Get Security Settings
Arguments
name- Required. The security settings to retrieve. Format:groups/{group_id}/securitySettings
Sourcepub fn list(&self) -> GroupListCall<'a, C>
pub fn list(&self) -> GroupListCall<'a, C>
Create a builder to help you perform the following task:
Lists the Group resources under a customer or namespace.
Sourcepub fn lookup(&self) -> GroupLookupCall<'a, C>
pub fn lookup(&self) -> GroupLookupCall<'a, C>
Create a builder to help you perform the following task:
Looks up the resource name of a Group by its EntityKey.
Sourcepub fn patch(&self, request: Group, name: &str) -> GroupPatchCall<'a, C>
pub fn patch(&self, request: Group, name: &str) -> GroupPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates a Group.
Arguments
request- No description provided.name- Output only. The resource name of theGroup. Shall be of the formgroups/{group}.
Sourcepub fn search(&self) -> GroupSearchCall<'a, C>
pub fn search(&self) -> GroupSearchCall<'a, C>
Create a builder to help you perform the following task:
Searches for Group resources matching a specified query.
Sourcepub fn update_security_settings(
&self,
request: SecuritySettings,
name: &str,
) -> GroupUpdateSecuritySettingCall<'a, C>
pub fn update_security_settings( &self, request: SecuritySettings, name: &str, ) -> GroupUpdateSecuritySettingCall<'a, C>
Create a builder to help you perform the following task:
Update Security Settings
Arguments
request- No description provided.name- Output only. The resource name of the security settings. Shall be of the formgroups/{group_id}/securitySettings.