pub struct LookupGroupNameResponse {
pub name: Option<String>,
}Expand description
The response message for GroupsService.LookupGroupName.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- lookup groups (response)
Fields
name: Option<String>The resource name of the looked-up Group.