pub struct Membership {
pub create_time: Option<DateTime<Utc>>,
pub delivery_setting: Option<String>,
pub name: Option<String>,
pub preferred_member_key: Option<EntityKey>,
pub roles: Option<Vec<MembershipRole>>,
pub type_: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A membership within the Cloud Identity Groups API. A Membership defines a relationship between a Group and an entity belonging to that Group, referred to as a “member”.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- memberships create groups (request)
- memberships get groups (response)
Fields
create_time: Option<DateTime<Utc>>Output only. The time when the Membership was created.
delivery_setting: Option<String>Output only. Delivery setting associated with the membership.
name: Option<String>Output only. The resource name of the Membership. Shall be of the form groups/{group}/memberships/{membership}.
preferred_member_key: Option<EntityKey>Required. Immutable. The EntityKey of the member.
roles: Option<Vec<MembershipRole>>The MembershipRoles that apply to the Membership. If unspecified, defaults to a single MembershipRole with name MEMBER. Must not contain duplicate MembershipRoles with the same name.
type_: Option<String>Output only. The type of the membership.
update_time: Option<DateTime<Utc>>Output only. The time when the Membership was last updated.